summaryrefslogtreecommitdiffstats
path: root/net/test
diff options
context:
space:
mode:
Diffstat (limited to 'net/test')
-rw-r--r--net/test/test_server.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/net/test/test_server.cc b/net/test/test_server.cc
index 683cde2..562e3e3 100644
--- a/net/test/test_server.cc
+++ b/net/test/test_server.cc
@@ -36,11 +36,12 @@
namespace {
-// Number of connection attempts for tests.
-const int kServerConnectionAttempts = 10;
+// Number of connection attempts for tests. With a timeout of 100ms, this is 60
+// seconds.
+const int kServerConnectionAttempts = 600;
// Connection timeout in milliseconds for tests.
-const int kServerConnectionTimeoutMs = 1000;
+const int kServerConnectionTimeoutMs = 100;
} // namespace